@@ -7,6 +7,7 @@ import bids.layout
 import json
 import csv
 import os
+import re
 from pathlib import Path
 from bids.layout import parse_file_entities
 from bids.utils import listify
@@ -60,7 +61,11 @@ class CuBIDS(object):
 
     def reset_bids_layout(self, validate=False):
         # create BIDS Layout Indexer class
-        indexer = bids.BIDSLayoutIndexer(validate=validate, ignore="*/.*")
+        ignores = ["code", "stimuli", "sourcedata", "models",
+                   re.compile(r'^\.'), re.compile(r'/\.')]
+        indexer = bids.BIDSLayoutIndexer(validate=validate,
+                                         ignore=ignores,
+                                         index_metadata=False)
 
         self._layout = bids.BIDSLayout(self.path,
                                        validate=validate,
@@ -161,7 +166,6 @@ class CuBIDS(object):
                 # add nifti info to corresponding sidecars​
                 sidecar = img_to_new_ext(str(path), '.json')
                 if Path(sidecar).exists():
-
                     with open(sidecar) as f:
                         data = json.load(f)
 
@@ -193,7 +197,7 @@ class CuBIDS(object):
 
         if self.use_datalad:
             self.datalad_save(message="Added nifti info to sidecars")
-            self.reset_bids_layout()
+        self.reset_bids_layout()
 
     def apply_tsv_changes(self, summary_tsv, files_tsv, new_prefix,
                           raise_on_error=True):
@@ -421,10 +425,12 @@ class CuBIDS(object):
         self.new_filenames.append(new_path)
 
         # NOW NEED TO RENAME ASSOCIATIONS
-        bids_file = self.layout.get_file(filepath)
-        associations = bids_file.get_associations()
-        for assoc in associations:
-            assoc_path = assoc.path
+        # bids_file = self.layout.get_file(filepath)
+        bids_file = filepath
+        # associations = bids_file.get_associations()
+        associations = self.get_nifti_associations(str(bids_file))
+        for assoc_path in associations:
+            # assoc_path = assoc.path
             if Path(assoc_path).exists():
                 # print("FILE: ", filepath)
                 # print("ASSOC: ", assoc.path)
@@ -432,7 +438,7 @@ class CuBIDS(object):
                 if '.nii' not in str(assoc_path):
                     self.old_filenames.append(assoc_path)
                     new_ext_path = img_to_new_ext(new_path,
-                                                  ''.join(Path(assoc.path)
+                                                  ''.join(Path(assoc_path)
                                                           .suffixes))
                     self.new_filenames.append(new_ext_path)
 
@@ -484,8 +490,9 @@ class CuBIDS(object):
         ses_path = self.path + '/' + sub + '/' + ses
         for path in Path(ses_path).rglob("fmap/*.json"):
             self.IF_rename_paths.append(str(path))
-            json_file = self.layout.get_file(str(path))
-            data = json_file.get_dict()
+            # json_file = self.layout.get_file(str(path))
+            # data = json_file.get_dict()
+            data = get_sidecar_metadata(str(path))
 
             if 'IntendedFor' in data.keys():
                 # check if IntendedFor field is a str or list
@@ -497,7 +504,7 @@ class CuBIDS(object):
                                 _get_intended_for_reference(new_path)
 
                         # update the json with the new data dictionary
-                        _update_json(json_file.path, data)
+                        _update_json(str(path), data)
 
                 if isinstance(data['IntendedFor'], list):
                     for item in data['IntendedFor']:
@@ -510,7 +517,7 @@ class CuBIDS(object):
                                     _get_intended_for_reference(new_path))
 
                         # update the json with the new data dictionary
-                        _update_json(json_file.path, data)
+                        _update_json(str(path), data)
 
         # save IntendedFor purges so that you can datalad run the
         # remove association file commands on a clean dataset
@@ -614,9 +621,9 @@ class CuBIDS(object):
 
         for path in Path(self.path).rglob("sub-*/*/fmap/*.json"):
 
-            json_file = self.layout.get_file(str(path))
-
-            data = json_file.get_dict()
+            # json_file = self.layout.get_file(str(path))
+            # data = json_file.get_dict()
+            data = get_sidecar_metadata(str(path))
 
             # remove scan references in the IntendedFor
 
@@ -626,7 +633,7 @@ class CuBIDS(object):
                     if data['IntendedFor'] in if_scans:
                         data['IntendedFor'] = []
                         # update the json with the new data dictionary
-                        _update_json(json_file.path, data)
+                        _update_json(str(path), data)
 
                 if isinstance(data['IntendedFor'], list):
                     for item in data['IntendedFor']:
@@ -634,7 +641,7 @@ class CuBIDS(object):
                             data['IntendedFor'].remove(item)
 
                             # update the json with the new data dictionary
-                            _update_json(json_file.path, data)
+                            _update_json(str(path), data)
 
         # save IntendedFor purges so that you can datalad run the
         # remove association file commands on a clean dataset
@@ -653,15 +660,16 @@ class CuBIDS(object):
         for path in Path(self.path).rglob("sub-*/**/*.nii.gz"):
 
             if str(path) in scans:
-                bids_file = self.layout.get_file(str(path))
-                associations = bids_file.get_associations()
-
+                # bids_file = self.layout.get_file(str(path))
+                # associations = bids_file.get_associations()
+                associations = self.get_nifti_associations(str(path))
                 for assoc in associations:
-                    filepath = assoc.path
+                    to_remove.append(assoc)
+                    # filepath = assoc.path
+
+            # ensure association is not an IntendedFor reference!
+            if '.nii' not in str(path):
 
-                    # ensure association is not an IntendedFor reference!
-                    if '.nii' not in str(filepath):
-                        to_remove.append(filepath)
                 if '/dwi/' in str(path):
                     # add the bval and bvec if there
                     if Path(img_to_new_ext(str(path), '.bval')).exists():
@@ -715,6 +723,15 @@ class CuBIDS(object):
         else:
             print("Not running any association removals")
 
+    def get_nifti_associations(self, nifti):
+        # get all assocation files of a nifti image
+        no_ext_file = str(nifti).split('/')[-1].split('.')[0]
+        associations = []
+        for path in Path(self.path).rglob("sub-*/**/*.*"):
+            if no_ext_file in str(path) and '.nii.gz' not in str(path):
+                associations.append(str(path))
+        return associations
+
     def _cache_fieldmaps(self):
         """Searches all fieldmaps and creates a lookup for each file.
 
@@ -728,10 +745,14 @@ class CuBIDS(object):
         suffix = '(phase1|phasediff|epi|fieldmap)'
         fmap_files = self.layout.get(suffix=suffix, regex_search=True,
                                      extension=['.nii.gz', '.nii'])
+
         misfits = []
         files_to_fmaps = defaultdict(list)
         for fmap_file in tqdm(fmap_files):
-            intentions = listify(fmap_file.get_metadata().get("IntendedFor"))
+            # intentions = listify(fmap_file.get_metadata().get("IntendedFor"))
+            fmap_json = img_to_new_ext(fmap_file.path, '.json')
+            if_list = get_sidecar_metadata(fmap_json).get("IntendedFor")
+            intentions = listify(if_list)
             subject_prefix = "sub-%s" % fmap_file.entities['subject']
 
             if intentions is not None:
@@ -1156,8 +1177,8 @@ class CuBIDS(object):
 
         for bidsfile in files_to_change:
             # get the sidecar file
-            bidsjson_file = bidsfile.get_associations()
-
+            # bidsjson_file = bidsfile.get_associations()
+            bidsjson_file = img_to_new_ext(str(bidsfile), '.json')
             if not bidsjson_file:
                 print("NO JSON FILES FOUND IN ASSOCIATIONS")
                 continue
@@ -1312,7 +1333,8 @@ def _get_param_groups(files, layout, fieldmap_lookup, key_group_name,
     dfs = []
     # path needs to be relative to the root with no leading prefix
     for path in files:
-        metadata = layout.get_metadata(path)
+        # metadata = layout.get_metadata(path)
+        metadata = get_sidecar_metadata(img_to_new_ext(path, '.json'))
         intentions = metadata.get("IntendedFor", [])
         slice_times = metadata.get("SliceTiming", [])
 
@@ -1442,6 +1464,14 @@ def round_params(param_group_df, config, modality):
     return param_group_df
 
 
+def get_sidecar_metadata(json_file):
+    # get all metadata values in a file's sidecar
+    # transform json dictionary to python dictionary
+    with open(json_file) as json_file:
+        data = json.load(json_file)
+    return data
+
+
 def format_params(param_group_df, config, modality):
     '''Run AgglomerativeClustering on param groups, add columns to dataframe'''
 
